@@ -211,6 +211,12 @@ static void UnapplyCursorState(OOMouseInteractionMode mode);
 }
 
 
+- (NSSize) backingViewSize
+{
+	return backingViewSize;
+}
+
+
 - (GLfloat) display_z
 {
 	return display_z;
@@ -338,7 +344,11 @@ static void UnapplyCursorState(OOMouseInteractionMode mode);
 	if ([self respondsToSelector:@selector(convertSizeToBacking:)])
 	{
 		// High resolution mode support.
-		v_size = [self convertSizeToBacking:v_size];
+		backingViewSize = [self convertSizeToBacking:viewSize];
+	}
+	else
+	{
+		backingViewSize = viewSize;
 	}
 	
 	[self openGLContext];	// Force lazy setup if needed.
@@ -386,12 +396,7 @@ static void UnapplyCursorState(OOMouseInteractionMode mode);
 - (BOOL) snapShot:(NSString *)filename
 {
 	BOOL snapShotOK = YES;
-        NSSize v_size = viewSize;
-	if ([self respondsToSelector:@selector(convertSizeToBacking:)])
-	{
-		// High resolution mode support.
-		v_size = [self convertSizeToBacking:v_size];
-	}
+	NSSize v_size = backingViewSize;
 	
 	int w = v_size.width;
 	int h = v_size.height;
@@ -504,6 +509,12 @@ FAIL:
 }
 
 
+- (void) stringToClipboard:(NSString *)stringToCopy
+{
+	// TODO: implement string clipboard copy for Mac
+}
+
+
 - (BOOL) acceptsFirstResponder
 {
 	return YES;
@@ -690,6 +701,10 @@ FAIL:
 	ctrl = (flags & NSControlKeyMask) ? YES : NO;
 	command = (flags & NSCommandKeyMask) ? YES : NO;
 	shift = ( flags & NSShiftKeyMask ) ? YES : NO;
+	if ([theEvent keyCode] == 0x39) // 57 = key code for caps lock
+	{
+		capsLockOn = (flags & NSAlphaShiftKeyMask) ? YES : NO;
+	}
 }
 
 
@@ -723,7 +738,7 @@ FAIL:
 {
 	double mx = [theEvent locationInWindow].x - viewSize.width/2.0;
 	double my = [theEvent locationInWindow].y - viewSize.height/2.0;
-		
+
 	if (display_z > 640.0)
 	{
 		mx /= viewSize.width * MAIN_GUI_PIXEL_WIDTH / display_z;
@@ -975,6 +990,12 @@ FAIL:
 }
 
 
+- (BOOL) isCapsLockOn
+{
+	return capsLockOn;
+}
+
+
 - (int) numKeys
 {
 	return NUM_KEYS;
@@ -1047,7 +1068,7 @@ FAIL:
 		[bitmap autorelease];
 		
 		NSString *filepath = [[[[[NSBundle mainBundle] bundlePath] stringByDeletingLastPathComponent] stringByAppendingPathComponent:name] stringByAppendingPathExtension:@"png"];
-		[[bitmap representationUsingType:NSPNGFileType properties:nil] writeToFile:filepath atomically:YES];
+		[[bitmap representationUsingType:NSPNGFileType properties:[NSDictionary dictionary]] writeToFile:filepath atomically:YES];
 	}
 }
 
@@ -1075,7 +1096,7 @@ FAIL:
 		[bitmap autorelease];
 		
 		NSString *filepath = [[[[[NSBundle mainBundle] bundlePath] stringByDeletingLastPathComponent] stringByAppendingPathComponent:name] stringByAppendingPathExtension:@"png"];
-		[[bitmap representationUsingType:NSPNGFileType properties:nil] writeToFile:filepath atomically:YES];
+		[[bitmap representationUsingType:NSPNGFileType properties:[NSDictionary dictionary]] writeToFile:filepath atomically:YES];
 	}
 }
 
@@ -1104,7 +1125,7 @@ FAIL:
 		[bitmap autorelease];
 		
 		NSString *filepath = [[[[[NSBundle mainBundle] bundlePath] stringByDeletingLastPathComponent] stringByAppendingPathComponent:name] stringByAppendingPathExtension:@"png"];
-		[[bitmap representationUsingType:NSPNGFileType properties:nil] writeToFile:filepath atomically:YES];
+		[[bitmap representationUsingType:NSPNGFileType properties:[NSDictionary dictionary]] writeToFile:filepath atomically:YES];
 	}
 }
 
@@ -1133,7 +1154,7 @@ FAIL:
 		[bitmap autorelease];
 		
 		NSString *filepath = [[[[[NSBundle mainBundle] bundlePath] stringByDeletingLastPathComponent] stringByAppendingPathComponent:name] stringByAppendingPathExtension:@"png"];
-		[[bitmap representationUsingType:NSPNGFileType properties:nil] writeToFile:filepath atomically:YES];
+		[[bitmap representationUsingType:NSPNGFileType properties:[NSDictionary dictionary]] writeToFile:filepath atomically:YES];
 	}
 }
 
@@ -1236,13 +1257,13 @@ static void UnapplyCursorState(OOMouseInteractionMode mode)
 
 - (void) setFov:(float)value fromFraction:(BOOL)fromFraction
 {
-	_fov = fromFraction ? value : tan((value / 2) * M_PI / 180);
+	_fov = fromFraction ? value : tanf((value / 2.0f) * M_PI / 180.0f);
 }
 
 
 - (float) fov:(BOOL)inFraction
 {
-	return inFraction ? _fov : 2 * atan(_fov) * 180 / M_PI;
+	return inFraction ? _fov : 2 * atanf(_fov) * 180.0f / M_PI;
 }
 
 @end
