@@ -4,7 +4,7 @@ OOSparkEntity.h
 
 
 Oolite
-Copyright (C) 2004-2011 Giles C Williams and contributors
+Copyright (C) 2004-2013 Giles C Williams and contributors
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -33,7 +33,7 @@ MA 02110-1301, USA.
 	GLfloat				_duration, _timeRemaining;
 }
 
-- (id) initWithPosition:(Vector)position
+- (id) initWithPosition:(HPVector)position
 			   velocity:(Vector)velocity
 			   duration:(OOTimeDelta)duration
 				   size:(float)size
