@@ -51,6 +51,8 @@ MA 02110-1301, USA.
 // reposition menu
 #define GUI_ROW(GROUP,ITEM) (GUI_FIRST_ROW(GROUP) - 4 + GUI_ROW_##GROUP##OPTIONS_##ITEM)
 
+#define CUSTOM_VIEW_MAX_ZOOM_IN		1.5
+#define CUSTOM_VIEW_MAX_ZOOM_OUT	25
 
 #define ENTRY(label, value) label,
 
@@ -111,6 +113,7 @@ typedef enum
 #define CHART_SCROLL_AT_Y		31.0
 #define CHART_CLIP_BORDER		10.0
 #define CHART_SCREEN_VERTICAL_CENTRE	(10*MAIN_GUI_ROW_HEIGHT)
+#define CHART_SCREEN_VERTICAL_CENTRE_COMPACT	(7*MAIN_GUI_ROW_HEIGHT)
 #define CHART_ZOOM_SPEED_FACTOR		1.05
 
 #define CHART_ZOOM_SHOW_LABELS		2.0
@@ -140,6 +143,7 @@ enum
 	
 	STATUS_EQUIPMENT_FIRST_ROW 			= 10,
 	STATUS_EQUIPMENT_MAX_ROWS 			= 8,
+	STATUS_EQUIPMENT_BIGGUI_EXTRA_ROWS	= 6,
 
 	GUI_ROW_EQUIPMENT_START				= 3,
 	GUI_MAX_ROWS_EQUIPMENT				= 12,
@@ -161,8 +165,10 @@ enum
 	GUI_MAX_ROWS_SCENARIOS				= 12,
 	GUI_ROW_SCENARIOS_DETAIL			= GUI_ROW_SCENARIOS_START + GUI_MAX_ROWS_SCENARIOS + 2,
 	GUI_ROW_CHART_SYSTEM				= 19,
+	GUI_ROW_CHART_SYSTEM_COMPACT		= 17,
 	GUI_ROW_PLANET_FINDER				= 20
 };
+
 #if GUI_FIRST_ROW() < 0
 # error Too many items in OPTIONS list!
 #endif
@@ -356,6 +362,7 @@ typedef enum
 @private
 	OOSystemID				system_id;
 	OOSystemID				target_system_id;
+	OOSystemID				info_system_id;
 
 	float					occlusion_dial;
 	
@@ -478,11 +485,11 @@ typedef enum
 	OOCargoQuantity			current_cargo;
 	
 	NSPoint					cursor_coordinates;
-	NSPoint					chart_cursor_coordinates;
 	NSPoint					chart_focus_coordinates;
 	NSPoint					chart_centre_coordinates;
 	// where we want the chart centre to be - used for smooth transitions
 	NSPoint					target_chart_centre;
+	NSPoint					target_chart_focus;
 	// Chart zoom is 1.0 when fully zoomed in and increases as we zoom out.  The reason I've done it that way round
 	// is because we might want to implement bigger galaxies one day, and thus may need to zoom out indefinitely.
 	OOScalar				chart_zoom;
@@ -581,6 +588,8 @@ typedef enum
 	OOKeyCode				key_docking_music;
 	
 	OOKeyCode				key_advanced_nav_array;
+	OOKeyCode				key_info_next_system;
+	OOKeyCode				key_info_previous_system;
 	OOKeyCode				key_map_home;
 	OOKeyCode				key_map_info;
 	
@@ -639,12 +648,12 @@ typedef enum
 	// target memory
 	// TODO: this should use weakrefs
 	NSMutableArray  		*target_memory;
-	int						target_memory_index;
+	NSUInteger				target_memory_index;
 	
 	// custom view points
 	Quaternion				customViewQuaternion;
 	OOMatrix				customViewMatrix;
-	Vector					customViewOffset, customViewForwardVector, customViewUpVector, customViewRightVector;
+	Vector					customViewOffset, customViewForwardVector, customViewUpVector, customViewRightVector, customViewRotationCenter;
 	NSString				*customViewDescription;
 	
 	
@@ -717,7 +726,7 @@ typedef enum
 	WormholeEntity			*wormhole;
 
 	ShipEntity				*demoShip; // Used while docked to maintain demo ship rotation.
-	OOLaserShotEntity *lastShot; // used to correctly position laser shots on first frame of firing
+	NSArray                 *lastShot; // used to correctly position laser shots on first frame of firing
 	
 	StickProfileScreen		*stickProfileScreen;
 
@@ -773,6 +782,13 @@ typedef enum
 - (OOSystemID) targetSystemID;
 - (void) setTargetSystemID:(OOSystemID) sid;
 - (OOSystemID) nextHopTargetSystemID;
+- (OOSystemID) infoSystemID;
+- (void) setInfoSystemID: (OOSystemID) sid moveChart:(BOOL) moveChart;
+- (void) nextInfoSystem;
+- (void) previousInfoSystem;
+- (void) homeInfoSystem;
+- (void) targetInfoSystem;
+- (BOOL) infoSystemOnRoute;
 
 
 - (NSDictionary *) commanderDataDictionary;
@@ -938,7 +954,7 @@ typedef enum
 
 - (OOWeaponType) weaponForFacing:(OOWeaponFacing)facing;
 - (OOWeaponType) currentWeapon;
-- (Vector) currentLaserOffset;
+- (NSArray *) currentLaserOffset;
 
 - (void) rotateCargo;
 
@@ -999,6 +1015,8 @@ typedef enum
 - (void) showInformationForSelectedUpgrade;
 - (void) showInformationForSelectedUpgradeWithFormatString:(NSString *)extraString;
 - (BOOL) setWeaponMount:(OOWeaponFacing)chosen_weapon_facing toWeapon:(NSString *)eqKey;
+- (BOOL) setWeaponMount:(OOWeaponFacing)facing toWeapon:(NSString *)eqKey inContext:(NSString *) context;
+
 - (BOOL) changePassengerBerths:(int) addRemove;
 - (OOCargoQuantity) cargoQuantityForType:(OOCommodityType)type;
 - (OOCargoQuantity) setCargoQuantityForType:(OOCommodityType)type amount:(OOCargoQuantity)amount;
@@ -1063,7 +1081,7 @@ typedef enum
 
 - (void) clearTargetMemory;
 - (NSMutableArray *) targetMemory;
-- (BOOL) moveTargetMemoryBy:(int)delta;
+- (BOOL) moveTargetMemoryBy:(NSInteger)delta;
 
 - (void) printIdentLockedOnForMissile:(BOOL)missile;
 
@@ -1073,13 +1091,30 @@ typedef enum
 
 // custom view points
 - (Quaternion)customViewQuaternion;
+- (void)setCustomViewQuaternion:(Quaternion)q1;
 - (OOMatrix)customViewMatrix;
 - (Vector)customViewOffset;
+- (void)setCustomViewOffset:(Vector)offset;
+- (Vector)customViewRotationCenter;
+- (void)setCustomViewRotationCenter:(Vector)center;
+- (void)customViewZoomOut:(OOScalar) rate;
+- (void)customViewZoomIn: (OOScalar) rate;
+- (void)customViewRotateLeft:(OOScalar) angle;
+- (void)customViewRotateRight:(OOScalar) angle;
+- (void)customViewRotateUp:(OOScalar) angle;
+- (void)customViewRotateDown:(OOScalar) angle;
+- (void)customViewRollLeft:(OOScalar) angle;
+- (void)customViewRollRight:(OOScalar) angle;
+- (void)customViewPanUp:(OOScalar) angle;
+- (void)customViewPanDown:(OOScalar) angle;
+- (void)customViewPanLeft:(OOScalar) angle;
+- (void)customViewPanRight:(OOScalar) angle;
 - (Vector)customViewForwardVector;
 - (Vector)customViewUpVector;
 - (Vector)customViewRightVector;
 - (NSString *)customViewDescription;
 - (void)resetCustomView;
+- (void)setCustomViewData;
 - (void)setCustomViewDataFromDictionary:(NSDictionary*) viewDict withScaling:(BOOL)withScaling;
 - (HPVector) viewpointPosition;
 - (HPVector) breakPatternPosition;
@@ -1150,7 +1185,7 @@ typedef enum
 - (BOOL) removeMissionDestinationMarker:(NSDictionary *)marker;
 - (NSMutableDictionary*) getMissionDestinations;
 
-- (void) setLastShot:(OOLaserShotEntity *)shot;
+- (void) setLastShot:(NSArray *)shot;
 
 - (void) showShipModelWithKey:(NSString *)shipKey shipData:(NSDictionary *)shipData personality:(uint16_t)personality factorX:(GLfloat)factorX factorY:(GLfloat)factorY factorZ:(GLfloat)factorZ inContext:(NSString *)context;
 
