@@ -471,7 +471,7 @@ static void RemovePreference(NSString *key)
 			
 			// did we put the old directory in the trash?
 			Boolean inTrash = false;
-			const UInt8* utfPath = (UInt8*)[[url path] UTF8String];
+			const UInt8 *utfPath = (const UInt8 *)[[url path] UTF8String];
 			
 			OSStatus err = DetermineIfPathIsEnclosedByFolder(kOnAppropriateDisk, kTrashFolderType, utfPath, false, &inTrash);
 			// if so, create a new directory.
@@ -548,11 +548,11 @@ static void RemovePreference(NSString *key)
 	}
 	
 	// None found, create the default path.
-	[NSFileManager.defaultManager createDirectoryAtPath:paths[0]
+	[NSFileManager.defaultManager createDirectoryAtPath:[paths objectAtIndex:0]
 							withIntermediateDirectories:YES
 											 attributes:nil
 												  error:NULL];
-	[self openPath:paths[0]];
+	[self openPath:[paths objectAtIndex:0]];
 }
 
 
@@ -597,7 +597,7 @@ static void RemovePreference(NSString *key)
 	if (action == @selector(showAddOnsAction:))
 	{
 		// Always enabled in unrestricted mode, to allow users to add OXPs more easily.
-		return [ResourceManager useAddOns];
+		return [ResourceManager useAddOns] != nil;
 	}
 	
 	if (action == @selector(showSnapshotsAction:))
@@ -835,7 +835,7 @@ static NSMutableArray *sMessageStack;
 	[[OODebugMonitor sharedDebugMonitor] applicationWillTerminate];
 #endif
 	[[NSUserDefaults standardUserDefaults] synchronize];
-	OOLog(@"gameController.exitApp",@".GNUstepDefaults synchronized.");
+	OOLog(@"gameController.exitApp", @"%@", @".GNUstepDefaults synchronized.");
 	OOLoggingTerminate();
 	SDL_Quit();
 	[[OOOpenALController sharedController] shutdown];
