@@ -61,19 +61,6 @@ enum
 };
 
 
-@interface OOPlanetTextureGenerator (Private)
-
-- (NSString *) cacheKeyForType:(NSString *)type;
-- (OOTextureGenerator *) normalMapGenerator;	// Must be called before generator is enqueued for rendering.
-- (OOTextureGenerator *) atmosphereGenerator;	// Must be called before generator is enqueued for rendering.
-
-#if DEBUG_DUMP_RAW
-- (void) dumpNoiseBuffer:(float *)noise;
-#endif
-
-@end
-
-
 /*	The planet generator actually generates two textures when shaders are
 	active, but the texture loader interface assumes we only load/generate
 	one texture per loader. Rather than complicate that, we use a mock
@@ -82,6 +69,7 @@ enum
 @interface OOPlanetNormalMapGenerator: OOTextureGenerator
 {
 @private
+	BOOL					_enqueued;
 	NSString				*_cacheKey;
 	RANROTSeed				_seed;
 }
@@ -90,6 +78,8 @@ enum
 
 - (void) completeWithData:(void *)data width:(unsigned)width height:(unsigned)height;
 
+- (BOOL) enqueued;
+
 @end
 
 
@@ -97,6 +87,7 @@ enum
 @interface OOPlanetAtmosphereGenerator: OOTextureGenerator
 {
 @private
+	BOOL				_enqueued;
 	NSString				*_cacheKey;
 	RANROTSeed				_seed;
 	OOPlanetTextureGenerator	*_parent;
@@ -106,6 +97,21 @@ enum
 
 - (void) completeWithData:(void *)data width:(unsigned)width height:(unsigned)height;
 
+- (BOOL) enqueued;
+
+@end
+
+
+@interface OOPlanetTextureGenerator (Private)
+
+- (NSString *) cacheKeyForType:(NSString *)type;
+- (OOPlanetNormalMapGenerator *) normalMapGenerator;	// Must be called before generator is enqueued for rendering.
+- (OOPlanetAtmosphereGenerator *) atmosphereGenerator;	// Must be called before generator is enqueued for rendering.
+
+#if DEBUG_DUMP_RAW
+- (void) dumpNoiseBuffer:(float *)noise;
+#endif
+
 @end
 
 
@@ -148,12 +154,12 @@ enum
 
 - (id) initWithPlanetInfo:(NSDictionary *)planetInfo
 {
-	OOLog(@"texture.planet.generate",@"Initialising planetary generator");
+	OOLog(@"texture.planet.generate", @"%@", @"Initialising planetary generator");
 
 	// AllowCubeMap not used yet but might be in future
 	if ((self = [super initWithPath:[NSString stringWithFormat:@"OOPlanetTexture@%p", self] options:kOOTextureAllowCubeMap]))
 	{
-		OOLog(@"texture.planet.generate",@"Extracting parameters for generator %@",self);
+		OOLog(@"texture.planet.generate", @"Extracting parameters for generator %@",self);
 
 		_info.landFraction = OOClamp_0_1_f([planetInfo oo_floatForKey:@"land_fraction" defaultValue:0.3]);
 		_info.polarFraction = OOClamp_0_1_f([planetInfo oo_floatForKey:@"polar_fraction" defaultValue:0.05]);
@@ -164,7 +170,7 @@ enum
 		[[planetInfo objectForKey:@"noise_map_seed"] getValue:&_info.seed];
 		if ([planetInfo objectForKey:@"cloud_alpha"])
 		{
-			OOLog(@"texture.planet.generate",@"Extracting atmosphere parameters");
+			OOLog(@"texture.planet.generate", @"%@", @"Extracting atmosphere parameters");
 			// we have an atmosphere:
 			_info.cloudAlpha = [planetInfo oo_floatForKey:@"cloud_alpha" defaultValue:1.0f];
 			_info.cloudFraction = OOClamp_0_1_f([planetInfo oo_floatForKey:@"cloud_fraction" defaultValue:0.3]);
@@ -215,13 +221,13 @@ enum
 	OOPlanetTextureGenerator *diffuseGen = [[[self alloc] initWithPlanetInfo:planetInfo] autorelease];
 	if (diffuseGen == nil)  return NO;
 	
-	OOTextureGenerator *atmoGen = [diffuseGen atmosphereGenerator];
+	OOPlanetAtmosphereGenerator *atmoGen = [diffuseGen atmosphereGenerator];
 	if (atmoGen == nil)  return NO;
 	
 	*atmosphere = [OOTexture textureWithGenerator:atmoGen];
 	if (*atmosphere == nil)  return NO;
 	
-	*texture = [OOTexture textureWithGenerator:diffuseGen];
+	*texture = [OOTexture textureWithGenerator:diffuseGen enqueue: [atmoGen enqueued]];
 	
 	return *texture != nil;
 }
@@ -230,20 +236,23 @@ enum
 + (BOOL) generatePlanetTexture:(OOTexture **)texture secondaryTexture:(OOTexture **)secondaryTexture withInfo:(NSDictionary *)planetInfo
 {
 	NSParameterAssert(texture != NULL);
+
+	BOOL enqueue = NO;
 	
 	OOPlanetTextureGenerator *diffuseGen = [[[self alloc] initWithPlanetInfo:planetInfo] autorelease];
 	if (diffuseGen == nil)  return NO;
 	
 	if (secondaryTexture != NULL)
 	{
-		OOTextureGenerator *normalGen = [diffuseGen normalMapGenerator];
+		OOPlanetNormalMapGenerator *normalGen = [diffuseGen normalMapGenerator];
 		if (normalGen == nil)  return NO;
 		
 		*secondaryTexture = [OOTexture textureWithGenerator:normalGen];
 		if (*secondaryTexture == nil)  return NO;
+		enqueue = [normalGen enqueued];
 	}
 	
-	*texture = [OOTexture textureWithGenerator:diffuseGen];
+	*texture = [OOTexture textureWithGenerator:diffuseGen enqueue: enqueue];
 	
 	return *texture != nil;
 }
@@ -253,19 +262,22 @@ enum
 {
 	NSParameterAssert(texture != NULL);
 	
+	BOOL enqueue = NO;
+
 	OOPlanetTextureGenerator *diffuseGen = [[[self alloc] initWithPlanetInfo:planetInfo] autorelease];
 	if (diffuseGen == nil)  return NO;
 	
 	if (secondaryTexture != NULL)
 	{
-		OOTextureGenerator *normalGen = [diffuseGen normalMapGenerator];
+		OOPlanetNormalMapGenerator *normalGen = [diffuseGen normalMapGenerator];
 		if (normalGen == nil)  return NO;
 		
 		*secondaryTexture = [OOTexture textureWithGenerator:normalGen];
 		if (*secondaryTexture == nil)  return NO;
+		enqueue = [normalGen enqueued];
 	}
 	
-	OOTextureGenerator *atmoGen = [diffuseGen atmosphereGenerator];
+	OOPlanetAtmosphereGenerator *atmoGen = [diffuseGen atmosphereGenerator];
 	if (atmoGen == nil)  return NO;
 	
 	*atmosphere = [OOTexture textureWithGenerator:atmoGen];
@@ -276,10 +288,11 @@ enum
 		}
 		return NO;
 	}
+	enqueue = enqueue || [atmoGen enqueued];
 
 	OOLog(@"texture.planet.generate",@"Generator %@ has atmosphere %@",diffuseGen,*atmosphere);
 	
-	*texture = [OOTexture textureWithGenerator:diffuseGen];
+	*texture = [OOTexture textureWithGenerator:diffuseGen enqueue: enqueue];
 	return *texture != nil;
 }
 
@@ -325,7 +338,7 @@ enum
 }
 
 
-- (OOTextureGenerator *) normalMapGenerator
+- (OOPlanetNormalMapGenerator *) normalMapGenerator
 {
 	if (_nMapGenerator == nil)
 	{
@@ -335,7 +348,7 @@ enum
 }
 
 
-- (OOTextureGenerator *) atmosphereGenerator
+- (OOPlanetAtmosphereGenerator *) atmosphereGenerator
 {
 	if (_atmoGenerator == nil)
 	{
@@ -1178,6 +1191,7 @@ static void SetMixConstants(OOPlanetTextureGeneratorInfo *info, float temperatur
 	// AllowCubeMap not used yet but might be in future
 	if ((self = [super initWithPath:[NSString stringWithFormat:@"OOPlanetNormalTexture@%p", self] options:kOOTextureAllowCubeMap]))
 	{
+		_enqueued = NO;
 		_cacheKey = [cacheKey copy];
 		_seed = seed;
 	}
@@ -1212,10 +1226,17 @@ static void SetMixConstants(OOPlanetTextureGeneratorInfo *info, float temperatur
 		(The alternative would be for it to block a work thread waiting for
 		the real generator to complete, which seemed silly.)
 	*/
+	_enqueued = YES;
 	return YES;
 }
 
 
+- (BOOL) enqueued
+{
+	return _enqueued;
+}
+
+
 - (void) loadTexture
 {
 	// Do nothing.
@@ -1259,6 +1280,7 @@ static void SetMixConstants(OOPlanetTextureGeneratorInfo *info, float temperatur
 		_cacheKey = [cacheKey copy];
 		_seed = seed;
 		_parent = [parent retain];
+		_enqueued = NO;
 	}
 	return self;
 }
@@ -1286,10 +1308,17 @@ static void SetMixConstants(OOPlanetTextureGeneratorInfo *info, float temperatur
 
 - (BOOL) enqueue
 {
+	_enqueued = YES;
 	return YES;
 }
 
 
+- (BOOL) enqueued
+{
+	return _enqueued;
+}
+
+
 - (void) loadTexture
 {
 	// Do nothing.
@@ -1324,7 +1353,7 @@ static void SetMixConstants(OOPlanetTextureGeneratorInfo *info, float temperatur
 
 - (void) completeWithData:(void *)data_ width:(unsigned)width_ height:(unsigned)height_
 {
-	OOLog(@"texture.planet.generate",@"Completing atmosphere generator");
+	OOLog(@"texture.planet.generate", @"%@", @"Completing atmosphere generator");
 
 	_data = data_;
 	_width = width_;
