@@ -215,12 +215,18 @@ static NSString *sGlobalTraceContext = nil;
 
 
 + (id) textureWithGenerator:(OOTextureGenerator *)generator
+{
+	return [self textureWithGenerator:generator enqueue: NO];
+}
+
+
++ (id) textureWithGenerator:(OOTextureGenerator *)generator enqueue:(BOOL) enqueue
 {
 	if (generator == nil)  return nil;
 	
 #ifndef OOTEXTURE_NO_CACHE
 	OOTexture *existing = [OOTexture existingTextureForKey:[generator cacheKey]];
-	if (existing != nil)  return [[existing retain] autorelease];
+	if (existing != nil && !enqueue)  return [[existing retain] autorelease];
 #endif
 	
 	if (![generator enqueue])
@@ -337,7 +343,7 @@ static NSString *sGlobalTraceContext = nil;
 
 - (NSSize)texCoordsScale
 {
-	return NSMakeSize(1.0f, 1.0f);
+	return NSMakeSize(1.0, 1.0);
 }
 
 
