@@ -4,7 +4,7 @@ OOLogOutputHandler.m
 By Jens Ayton
 
 
-Copyright (C) 2007-2011 Jens Ayton and contributors
+Copyright (C) 2007-2013 Jens Ayton and contributors
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -28,7 +28,6 @@ SOFTWARE.
 
 
 #define OOLOG_POISON_NSLOG 0
-#define DLOPEN_NO_WARN
 
 #import "OOLogOutputHandler.h"
 #import "OOLogging.h"
@@ -36,6 +35,7 @@ SOFTWARE.
 #include <stdlib.h>
 #include <stdio.h>
 #import "NSThreadOOExtensions.h"
+#import "NSFileManagerOOExtensions.h"
 
 
 #undef NSLog		// We need to be able to call the real NSLog.
@@ -88,6 +88,7 @@ static BOOL DirectoryExistCreatingIfNecessary(NSString *path);
 
 @interface OOAsyncLogger: NSObject
 {
+@private
 	OOAsyncQueue		*messageQueue;
 	NSConditionLock		*threadStateMonitor;
 	NSFileHandle		*logFile;
@@ -260,10 +261,10 @@ enum
 		if ([fmgr fileExistsAtPath:logPath])
 		{
 			oldPath = [OOLogHandlerGetLogBasePath() stringByAppendingPathComponent:@"Previous.log"];
-			[fmgr removeFileAtPath:oldPath handler:nil];
-			if (![fmgr movePath:logPath toPath:oldPath handler:nil])
+			[fmgr oo_removeItemAtPath:oldPath];
+			if (![fmgr oo_moveItemAtPath:logPath toPath:oldPath])
 			{
-				if (![fmgr removeFileAtPath:logPath handler:nil])
+				if (![fmgr oo_removeItemAtPath:logPath])
 				{
 					NSLog(@"Log setup: could not move or delete existing log at %@, will log to stdout instead.", logPath);
 					OK = NO;
@@ -310,7 +311,7 @@ enum
 		// set up threadStateMonitor -- used as a binary semaphore of sorts to check when the worker thread starts and stops.
 		threadStateMonitor = [[NSConditionLock alloc] initWithCondition:kConditionReadyToDealloc];
 		if (threadStateMonitor == nil)  OK = NO;
-		[threadStateMonitor ooSetName:@"OOLogOutputHandler thread state monitor"];
+		[threadStateMonitor setName:@"OOLogOutputHandler thread state monitor"];
 	}
 	
 	if (OK)
@@ -420,7 +421,7 @@ enum
 {
 	id					message = nil;
 	NSAutoreleasePool	*rootPool = nil, *pool = nil;
-	OOUInteger			size = 0;
+	NSUInteger			size = 0;
 	
 	rootPool = [[NSAutoreleasePool alloc] init];
 	[NSThread ooSetCurrentThreadName:@"OOLogOutputHandler logging thread"];
@@ -430,7 +431,8 @@ enum
 	[threadStateMonitor lock];
 	[threadStateMonitor unlockWithCondition:kConditionWorking];
 	
-	NS_DURING
+	@try
+	{
 		for (;;)
 		{
 			pool = [[NSAutoreleasePool alloc] init];
@@ -464,8 +466,8 @@ enum
 			
 			[pool release];
 		}
-	NS_HANDLER
-	NS_ENDHANDLER
+	}
+	@catch (NSException *exception) {}
 	[pool release];
 	
 	// Clean up; after this, ivars are out of bounds.
@@ -558,7 +560,7 @@ static BOOL DirectoryExistCreatingIfNecessary(NSString *path)
 	}
 	if (!exists)
 	{
-		if (![fmgr createDirectoryAtPath:path attributes:nil])
+		if (![fmgr oo_createDirectoryAtPath:path attributes:nil])
 		{
 			NSLog(@"Log setup: could not create folder %@.", path);
 			return NO;
