@@ -136,7 +136,8 @@ materialDictionary:(NSDictionary *)materialDict
 			smooth:(BOOL)smooth
 	  shaderMacros:(NSDictionary *)macros
 shaderBindingTarget:(id<OOWeakReferenceSupport>)object
-	   scaleFactor:(float)scale;
+	   scaleFactor:(float)scale
+	cacheWriteable:(BOOL)cacheWriteable;
 
 - (BOOL) loadData:(NSString *)filename scaleFactor:(float)scale;
 - (void) checkNormalsAndAdjustWinding;
@@ -244,7 +245,8 @@ static BOOL IsPerVertexNormalMode(OOMeshNormalMode mode)
 								smooth:smooth
 						  shaderMacros:macros
 				   shaderBindingTarget:object
-						   scaleFactor:1.0f] autorelease];
+						   scaleFactor:1.0f
+						cacheWriteable:YES] autorelease];
 }
 
 + (instancetype) meshWithName:(NSString *)name
@@ -255,6 +257,7 @@ static BOOL IsPerVertexNormalMode(OOMeshNormalMode mode)
 				 shaderMacros:(NSDictionary *)macros
 		  shaderBindingTarget:(id<OOWeakReferenceSupport>)object
 				  scaleFactor:(float)scale
+			   cacheWriteable:(BOOL)cacheWriteable
 {
 	return [[[self alloc] initWithName:name
 							  cacheKey:cacheKey
@@ -263,7 +266,8 @@ static BOOL IsPerVertexNormalMode(OOMeshNormalMode mode)
 								smooth:smooth
 						  shaderMacros:macros
 				   shaderBindingTarget:object
-						   scaleFactor:scale] autorelease];
+						   scaleFactor:scale
+						cacheWriteable:cacheWriteable] autorelease];
 }
 
 
@@ -286,6 +290,8 @@ static BOOL IsPerVertexNormalMode(OOMeshNormalMode mode)
 	if (self == nil)  return nil;
 	
 	baseFile = @"No Model";
+	baseFileOctreeCacheRef = @"No Model-0.000";
+	_cacheWriteable = YES;
 #if OO_MULTITEXTURE
 	_textureUnitCount = NSNotFound;
 #endif
@@ -302,6 +308,7 @@ static BOOL IsPerVertexNormalMode(OOMeshNormalMode mode)
 {
 	unsigned				i;
 	
+	DESTROY(baseFileOctreeCacheRef);
 	DESTROY(baseFile);
 	DESTROY(octree);
 	
@@ -652,7 +659,7 @@ static NSString *NormalModeDescription(OOMeshNormalMode mode)
 {
 	if (octree == nil)
 	{
-		octree = [[OOCacheManager octreeForModel:baseFile] retain];
+		octree = [[OOCacheManager octreeForModel:baseFileOctreeCacheRef] retain];
 		if (octree == nil)
 		{
 			NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
@@ -671,10 +678,17 @@ static NSString *NormalModeDescription(OOMeshNormalMode mode)
 			
 			octree = [converter findOctreeToDepth:[self octreeDepth]];
 			[octree retain];
-			[OOCacheManager setOctree:octree forModel:baseFile];
+			if (EXPECT(_cacheWriteable))
+			{
+				[OOCacheManager setOctree:octree forModel:baseFileOctreeCacheRef];
+			}
 			
 			[pool release];
 		}
+		else
+		{
+			OOLog(@"mesh.load.octreeCached", @"Retrieved octree \"%@\" from cache.", baseFileOctreeCacheRef);
+		}
 	}
 	
 	return octree;
@@ -850,6 +864,7 @@ materialDictionary:(NSDictionary *)materialDict
 	  shaderMacros:(NSDictionary *)macros
 shaderBindingTarget:(id<OOWeakReferenceSupport>)target
 	   scaleFactor:(float)scale
+	cacheWriteable:(BOOL)cacheWriteable
 {
 	OOJS_PROFILE_ENTER
 	
@@ -858,6 +873,7 @@ shaderBindingTarget:(id<OOWeakReferenceSupport>)target
 	
 	NSAutoreleasePool* pool = [[NSAutoreleasePool alloc] init];
  	_normalMode = smooth ? kNormalModeSmooth : kNormalModePerFace;
+	_cacheWriteable = cacheWriteable;
 	
 #if OOMESH_PROFILE
 	_stopwatch = [[OOProfilingStopwatch alloc] init];
@@ -869,6 +885,7 @@ shaderBindingTarget:(id<OOWeakReferenceSupport>)target
 		PROFILE(@"finished calculateBoundingVolumes (again\?\?)");
 		
 		baseFile = [name copy];
+		baseFileOctreeCacheRef = [[NSString stringWithFormat:@"%@-%.3f", baseFile, scale] copy];
 		
 		/*	New in r3033: save the material-defining parameters here so we
 			can rebind the materials at any time.
@@ -917,6 +934,7 @@ shaderBindingTarget:(id<OOWeakReferenceSupport>)target
 	if (result != nil)
 	{
 		[result->baseFile retain];
+		[result->baseFileOctreeCacheRef retain];
 		[result->octree retain];
 		[result->_retainedObjects retain];
 		[result->_materialDict retain];
@@ -1154,7 +1172,7 @@ shaderBindingTarget:(id<OOWeakReferenceSupport>)target
 	
 	if (!using_preloaded)
 	{
-		OOLog(@"mesh.load.uncached", @"Mesh \"%@\" is not in cache, loading.", filename);
+		OOLog(@"mesh.load.uncached", @"Mesh \"%@\" is not in cache, loading.", cacheKey);
 		
 		NSCharacterSet	*whitespaceCharSet = [NSCharacterSet whitespaceCharacterSet];
 		NSCharacterSet	*whitespaceAndNewlineCharSet = [NSCharacterSet whitespaceAndNewlineCharacterSet];
@@ -1587,8 +1605,11 @@ shaderBindingTarget:(id<OOWeakReferenceSupport>)target
 		}
 		
 		// save the resulting data for possible reuse
-		[OOCacheManager setMeshData:[self modelData] forName:cacheKey];
-		PROFILE(@"saved to cache");
+		if (EXPECT(_cacheWriteable))
+		{
+			[OOCacheManager setMeshData:[self modelData] forName:cacheKey];
+			PROFILE(@"saved to cache");
+		}
 		
 		if (failFlag)
 		{
@@ -1662,7 +1683,6 @@ shaderBindingTarget:(id<OOWeakReferenceSupport>)target
 - (void) generateFaceTangents
 {
 	OOJS_PROFILE_ENTER
-	BOOL lighting_fix = [[NSUserDefaults standardUserDefaults] boolForKey: @"lighting-fix-tentative"];
 	
 	OOMeshFaceCount	i;
 	for (i = 0; i < faceCount; i++)
@@ -1688,28 +1708,14 @@ shaderBindingTarget:(id<OOWeakReferenceSupport>)target
 		GLfloat dtAB = face->t[1] - face->t[0];
 		GLfloat dtAC = face->t[2] - face->t[0];
 		
-		if (lighting_fix)
+		if (dsAC * dtAB > dsAB * dtAC)
 		{
-			if (dsAC * dtAB > dsAB * dtAC)
-			{
-				face->tangent = vector_subtract(vector_multiply_scalar(vProjAC, dtAB), vector_multiply_scalar(vProjAB, dtAC));
-			}
-			else
-			{
-				face->tangent = vector_subtract(vector_multiply_scalar(vProjAB, dtAC), vector_multiply_scalar(vProjAC, dtAB));
-			}
+			face->tangent = vector_normal(vector_subtract(vector_multiply_scalar(vProjAC, dtAB), vector_multiply_scalar(vProjAB, dtAC)));
 		}
 		else
 		{
-			if (dsAC * dtAB > dsAB * dtAC)
-			{
-				dsAB = -dsAB;
-				dsAC = -dsAC;
-			}
-			
-			Vector tangent = vector_subtract(vector_multiply_scalar(vProjAB, dsAC), vector_multiply_scalar(vProjAC, dsAB));
-			face->tangent = cross_product(nA, tangent);	// Rotate 90 degrees. Done this way because I'm too lazy to grok the code above.
-		}
+			face->tangent = vector_normal(vector_subtract(vector_multiply_scalar(vProjAB, dtAC), vector_multiply_scalar(vProjAC, dtAB)));
+		}			
 	}
 	
 	OOJS_PROFILE_EXIT_VOID
@@ -1758,6 +1764,7 @@ static float FaceArea(GLuint *vertIndices, Vector *vertices)
 		}
 		
 		normal_sum = vector_normal_or_fallback(normal_sum, kBasisZVector);
+		tangent_sum = vector_subtract(tangent_sum, vector_multiply_scalar(normal_sum, dot_product(tangent_sum, normal_sum)));
 		tangent_sum = vector_normal_or_fallback(tangent_sum, kBasisXVector);
 		
 		_normals[i] = normal_sum;
@@ -1823,6 +1830,7 @@ static float FaceAreaCorrect(GLuint *vertIndices, Vector *vertices)
 			tangent_sum = vector_add(tangent_sum, vector_multiply_scalar(_faces[j].tangent, t));
 		}
 		
+		tangent_sum = vector_subtract(tangent_sum, vector_multiply_scalar(_normals[i], dot_product(_normals[i], tangent_sum)));
 		tangent_sum = vector_normal_or_fallback(tangent_sum, kBasisXVector);
 		
 		_tangents[i] = tangent_sum;
@@ -1962,7 +1970,7 @@ static float FaceAreaCorrect(GLuint *vertIndices, Vector *vertices)
 	OOJS_PROFILE_ENTER
 	
 	OOMeshVertexCount	i;
-	double				d_squared, length_longest_axis, length_shortest_axis;
+	float				d_squared, length_longest_axis, length_shortest_axis;
 	GLfloat				result;
 	
 	result = 0.0f;
@@ -1991,7 +1999,7 @@ static float FaceAreaCorrect(GLuint *vertIndices, Vector *vertices)
 	d_squared = (length_longest_axis + length_shortest_axis) * (length_longest_axis + length_shortest_axis) * 0.25; // square of average length
 	maxDrawDistance = d_squared * NO_DRAW_DISTANCE_FACTOR * NO_DRAW_DISTANCE_FACTOR;	// no longer based on the collision radius
 	
-	collisionRadius = sqrt(result);
+	collisionRadius = sqrtf(result);
 	
 	OOJS_PROFILE_EXIT_VOID
 }
@@ -2019,6 +2027,7 @@ static float FaceAreaCorrect(GLuint *vertIndices, Vector *vertices)
 	[self calculateBoundingVolumes];
 	DESTROY(octree);
 	DESTROY(baseFile);	// Avoid octree cache.
+	DESTROY(baseFileOctreeCacheRef);
 }
 
 
