@@ -118,8 +118,8 @@ static NSString *kOOSystemLayerProperty = @"layer";
 				if (distanceBetweenPlanetPositions(coordinatesCache[jIndex].x,coordinatesCache[jIndex].y,coordinatesCache[kIndex].x,coordinatesCache[kIndex].y) <= MAX_JUMP_RANGE)
 				{
 					// arrays are of system number only
-					[neighbourCache[jIndex] addObject:[NSNumber numberWithInt:k]];
-					[neighbourCache[kIndex] addObject:[NSNumber numberWithInt:j]];
+					[neighbourCache[jIndex] addObject:[NSNumber numberWithUnsignedInteger:k]];
+					[neighbourCache[kIndex] addObject:[NSNumber numberWithUnsignedInteger:j]];
 				}
 			}
 		}
@@ -300,7 +300,7 @@ static NSString *kOOSystemLayerProperty = @"layer";
 				[self setProperty:@"sun_radius"
 					 forSystemKey:systemKey
 						 andLayer:OO_LAYER_OXP_DYNAMIC
-						  toValue:[NSNumber numberWithFloat:sr_num+600000.0]
+						  toValue:[NSNumber numberWithFloat:sr_num+600000.0f]
 					 fromManifest:defaultManifest];
 			}
 		}
@@ -330,7 +330,7 @@ static NSString *kOOSystemLayerProperty = @"layer";
 	}
 	else
 	{
-		OOLog(@"system.description.error",@"getPropertiesForCurrentSystem called while player in interstellar space. This is an internal error. Please report it.");
+		OOLog(@"system.description.error", @"%@", @"getPropertiesForCurrentSystem called while player in interstellar space. This is an internal error. Please report it.");
 		// this shouldn't be called for interstellar space
 		return [NSDictionary dictionary];
 	}
@@ -357,6 +357,18 @@ static NSString *kOOSystemLayerProperty = @"layer";
 }
 
 
+- (NSDictionary *) getPropertiesForSystem:(OOSystemID)s inGalaxy:(OOGalaxyID)g
+{
+	NSUInteger index = (g * OO_SYSTEMS_PER_GALAXY) + s;
+	if (index >= OO_SYSTEM_CACHE_LENGTH)
+	{
+		OOLog(@"system.description.error",@"'%u, %u' is an invalid system. This is an internal error. Please report it.",g,s);
+		return [NSDictionary dictionary];
+	}
+	return propertyCache[index];
+}
+
+
 - (id) getProperty:(NSString *)property forSystemKey:(NSString *)key
 {
 	return [self getProperty:property forSystemKey:key withUniversal:YES];
@@ -470,7 +482,7 @@ static NSString *kOOSystemLayerProperty = @"layer";
 
 - (void) setProperties:(NSDictionary *)properties inDescription:(OOSystemDescriptionEntry *)desc
 {
-	OOSystemLayer layer = [properties oo_unsignedIntegerForKey:kOOSystemLayerProperty defaultValue:OO_LAYER_OXP_STATIC];
+	OOSystemLayer layer = [properties oo_unsignedIntForKey:kOOSystemLayerProperty defaultValue:OO_LAYER_OXP_STATIC];
 	if (layer > OO_LAYER_OXP_PRIORITY)
 	{
 		OOLog(@"system.description.error",@"Layer %u is not a valid layer number in system information.",layer);
@@ -575,6 +587,7 @@ static NSString *kOOSystemLayerProperty = @"layer";
 		OOLog(@"system.description.error",@"'%d %d' is an invalid system key. This is an internal error. Please report it.",g,s);
 		return nil;
 	}
+
 	return neighbourCache[index];
 }
 
