@@ -534,7 +534,6 @@ enum
 - (unsigned) countShipsWithPrimaryRole:(NSString *)role inRange:(double)range ofEntity:(Entity *)entity;
 - (unsigned) countShipsWithPrimaryRole:(NSString *)role;
 - (unsigned) countShipsWithScanClass:(OOScanClass)scanClass inRange:(double)range ofEntity:(Entity *)entity;
-- (void) sendShipsWithPrimaryRole:(NSString *)role messageToAI:(NSString *)message;
 
 
 // General count/search methods. Pass range of -1 and entity of nil to search all of system.
@@ -641,7 +640,6 @@ enum
 - (NSString *) getSystemInhabitants:(OOSystemID) sys plural:(BOOL)plural;
 
 - (NSPoint) coordinatesForSystem:(OOSystemID)s;
-- (OOSystemID) findSystemAtCoords:(NSPoint) coords withGalaxy:(OOGalaxyID) gal;
 - (OOSystemID) findSystemFromName:(NSString *) sysName;
 
 /**
@@ -651,7 +649,9 @@ enum
 
 - (OOSystemID) findNeighbouringSystemToCoords:(NSPoint) coords withGalaxy:(OOGalaxyID) gal;
 - (OOSystemID) findConnectedSystemAtCoords:(NSPoint) coords withGalaxy:(OOGalaxyID) gal;
-- (OOSystemID) findSystemNumberAtCoords:(NSPoint) coords withGalaxy:(OOGalaxyID) gal;
+// old alias for findSystemNumberAtCoords
+- (OOSystemID) findSystemAtCoords:(NSPoint) coords withGalaxy:(OOGalaxyID) gal;
+- (OOSystemID) findSystemNumberAtCoords:(NSPoint) coords withGalaxy:(OOGalaxyID) gal includingHidden:(BOOL)hidden;
 - (NSPoint) findSystemCoordinatesWithPrefix:(NSString *) p_fix;
 - (NSPoint) findSystemCoordinatesWithPrefix:(NSString *) p_fix exactMatch:(BOOL) exactMatch;
 - (BOOL*) systemsFound;
@@ -720,6 +720,7 @@ enum
 - (void) handleOoliteException:(NSException *)ooliteException;
 
 - (GLfloat)airResistanceFactor;
+- (void) setAirResistanceFactor:(GLfloat)newFactor;
 
 // speech routines
 //
